#!/bin/sh

# THIS PRODUCT CONTAINS RESTRICTED MATERIALS OF IBM
# Product #5724-C94, 5724-E69, 5724-L72, (C) COPYRIGHT International Business Machines Corp., 2002-2005.
# All Rights Reserved * Licensed Materials - Property of IBM
# US Government Users Restricted Rights - Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
# Configuration Based Update Installer
#----------------------------------------------------------------------------------
# Command Descriptions
# 
# The '-fix' option specifies an eFix update.
# The '-fixpack' option specifies a FixPack update.
# The '-install' option specifies an install action.
# The '-uninstall' option specifies an uninstall action.
# The '-installDir' option specifies the product install root location.
# The '-fixDir' option specifies the eFix directory.
# The '-fixpackDir' option specifies the FixPack directory.
# The '-fixes' specifies a list of eFixes to install or uninstall.
# The '-fixpackID' specifies a FixPack to install or uninstall.
# The '-fixDetails' option displays eFix detail information.
# The '-fixpackDetails' option displays FixPack detail information.
# The '-prereqOverride' option overrides any installation prerequisites.
# The '<propertyFile>.properties' option specifies an externally supplied parameters file.
# The ''-productId'' option specifies a product ID to triggers generation of version files.
# The ''-productVersion'' option specifies product verion and is used with -productId.

#----------------------------------------------------------------------------------
# Launch Arguments:
#
# For EFix Processing:
#      updateProduct.sh <propertiesFile>
#               ( -installDir <product install root>
#                 [ -configProperties puiconfig.properties ]
#                 [ -fix ]
#                 [ -fixDir <fix repository root> ]
#                 [ -install | -uninstall | -uninstallAll ]
#                 [ -fixes <space delimited list of ifixes> ]
#                 [ -fixJars <space delimited list of ifix jars> ]
#                 [ -fixDetails ]
#                 [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) ]
#                 [ -prereqOverride ] ) |
#               ( -help | -? | /help | /? | -usage )
#
# For FixPack Processing:
#  updateProduct.sh <propertiesFile>
#              ( -installDir <product install root>
#                 [ -configProperties puiconfig.properties]
#                 [ -fixpack ]
#                 [ ( -install | -uninstall
#                 -fixpackDir <fixpack repository root>
#                 -fixpackID <FixPack ID>
#                 [ -wpcpOnly ( -wpcpInstallDir <Content Publisher install root> ) ]
#                 [ -includeOptional <space delimited list of components> ]
#                 [ -fixpackDetails ]  |
#                 [ -productId <product ID> -productVersion <product version>] ) |
#               ( -help | -? | /help | /? | -usage )
#----------------------------------------------------------------------------------

# set DEBUG_UPDATE=yes to turn on debugging statements
DEBUG_UPDATE=

success_rc=0
fail_rc=$?

LaunchTitle=$0

launchInstaller=
useLocalJDK=
prepareJDK=
useJavaHome=
checkSetup=
callSetup=
checkClientSetup=
callClientSetup=
failSetup=
testJDK=
copyJDK=
failedCopyJDK=
okCopyJDK=

currentDir=`dirname $0`        
PLATFORM=`uname`

#----------------------------------------------------------------------------------
#  Initialization and setup
#----------------------------------------------------------------------------------
echo Start of [ "$LaunchTitle" ]
echo Build 20061017_1508
echo
      
echo Verifying installer jar:
echo   [ PuiCommandline.jar ]
echo
if [ -f "$currentDir"/PuiCommandline.jar ] 
   then        

        if [ "$PLATFORM" = "OS400" ]
        then
        	JAVA_HOME="/QIBM/ProdData/Java400/jdk13"
                WP_CP_EXTRA="/QIBM/ProdData/java400/jt400ntv.jar:/QIBM/ProdData/http/public/jt400/lib/jt400.jar"
                WP_JAVA_PARAMS="$WP_JAVA_PARAMS -Dfile.encoding=${ENCODING} -Djava.version=1.3 -DpermissionHelper=com.ibm.websphere.update.delta.OS400PermissionHelper"
                WAS_PROD_BASE="/QIBM/ProdData/WebAS5/Base"
                INSTALLDIR=null
                NEXT=FALSE

                #cp "$WAS_PROD_BASE"/java/extlib/log.jar "$currentDir"/log.jar
                
                for VAR in $@
                do
		        if [ TRUE = "$NEXT" ]
		        then
		 		 INSTALLDIR=$VAR
		 		 NEXT=FALSE
		 		 break
		        fi

		        if [ -INSTALLDIR = "`echo $VAR | tr '[a-z]' '[A-Z]'`" ]
		        then
		 		 NEXT=TRUE
		        fi
                done

                echo $INSTALLDIR
                
                callSetup=1
        #else
            #PUI @PJB WAS home not needed
            #if [ "$WAS_HOME" ] 
            #   then 
            #      if [ -f "$WAS_HOME"/bin/setupCmdLine.sh ]
            #         then
            #           	  echo Attempting to locate setupClient.sh
            #           	  echo
            #              callSetup=1
            #         else
            #              failSetup=1
            #      fi
            #   else
            #        echo The WAS_HOME env variable MUST be set.  
            #        echo Exiting.
            #        echo
            #        exit $fail_rc
            #fi
        fi

   else
        echo The installer jar file does not exist.  
        echo Exiting.
        echo
        exit $fail_rc
fi     

#PUI @PJB  
#if [ "$failSetup" ]
#   then        
#	echo Unable to locate setupCmdLine.sh, this is usually located beneath your
#	echo WebSphere AppServer installation, in the 'bin' directory
#	echo
#	echo Exiting.	
#	echo
#	exit $fail_rc 
#fi

#if [ "$callSetup" ]
#   then 
#                         
#        if [ "$PLATFORM" = "OS400" ]
#           then
#               copyProductFile=1
#               launchInstaller=1
#           else
#               . $WAS_HOME/bin/setupCmdLine.sh
#               testJDK=1
#        fi
#fi
testJDK=1

if [ "$copyProductFile" ]
   then
        export SRC_FILE="$INSTALLDIR"/version/EXPRESS.product
        export TMP_FILE=/tmp/EXPRESS.product
        
        if [ ! -f $SRC_FILE ]
        then
              cp /qibm/proddata/portalserver5/version/EXPRESS.product $SRC_FILE
        fi
        
        ls -S $SRC_FILE | grep 1208 >/dev/null 2>&1
        
        if [ $? -eq 1 ]
        then
             system "COPY OBJ('"$SRC_FILE"') TOOBJ('"$TMP_FILE"') FROMCCSID(13488) TOCCSID(1208) DTAFMT(*TEXT) REPLACE(*YES) OWNER(*KEEP)"
             if [ $? = 0 ]
             then
                 sleep 1
                 mv $SRC_FILE "$INSTALLDIR"/version/EXPRESS.product_backup 
                 cp -f $TMP_FILE $SRC_FILE
                 chmod 755 $SRC_FILE
                 rm $TMP_FILE
             fi
        fi
fi  

if [ "$testJDK" ]
   then
        if [ -f "$JAVA_HOME"/bin/java ]
            then
                launchInstaller=1
                else
                echo The JDK was not found within the set JAVA_HOME:
                echo     JAVA_HOME: [ "$JAVA_HOME"/bin/java ]
                echo
                echo Exiting.
                echo
                exit $fail_rc
        fi           
fi  
      
#PLATFORM=`uname`
export PLATFORM
                 
	                   
#----------------------------------------------------------------------------------
# Set up library loading for native extfile libs
#----------------------------------------------------------------------------------

# Cases for platform specific goop.
case ${PLATFORM} in
        Linux)
                # Select the right arch library for the utils!
                OS_ARCH=`uname -m`
                case ${OS_ARCH} in
                    i386|i486|i586|i686|i786|i886|athlon)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/i386:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    ppc|ppc64)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/ppc32:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                    s390)
                        LD_LIBRARY_PATH=${currentDir}/lib/linux/s390:${LD_LIBRARY_PATH}
                        export LD_LIBRARY_PATH
                        ;;
                esac
                ;;
        SunOS|Solaris)
                LD_LIBRARY_PATH=${currentDir}/lib/solaris:${LD_LIBRARY_PATH}
                export LD_LIBRARY_PATH
                ;;
        HP-UX)
                SHLIB_PATH=${currentDir}/lib/hpux:${SHLIB_PATH}
                export SHLIB_PATH
                
                # Make sure this is executable or it won't load!
                if [ ! -x ${currentDir}/lib/hpux/libUnixFileUtils.sl ] ; then
                    chmod 755 ${currentDir}/lib/hpux/libUnixFileUtils.sl
                fi                 
                ;;
        AIX)    
                LIBPATH=${currentDir}/lib/aix:${LIBPATH}
                export LIBPATH
                ;;
        OS400)
        	;;
        *)
                echo "Unknown platform: ${PLATFORM}.  Native file libraries will not be loaded."
                ;;
esac


#----------------------------------------------------------------------------------
# Installer application execution
#----------------------------------------------------------------------------------

# DBG_PROP="-Dcom.ibm.websphere.update.ptf.log.level=5  -Dcom.ibm.ws.update.debug=true -Dcom.ibm.websphere.update.ptf.debug=true -Dcom.ibm.websphere.update.harness.debug=true"
# export DBG_PROP
PUI_PROP="-Dcom.ibm.websphere.update.wea=true"
export PUI_PROP


if [ "$launchInstaller" ] 
then                  
    "$JAVA_HOME"/bin/java \
    -Xmx256m \
    -cp "$WP_CP_EXTRA":"$currentDir"/PuiCommandline.jar:"$currentDir"/lib/extfile.jar \
    -DCURRENT_UPDATE_DIR="${currentDir}" \
    -DWAS_PROD_BASE_PATH="$WAS_PROD_BASE" \
    ${PUI_PROP} \
    -Dcom.ibm.wp.pui.bld.level=20061017_1508 \
    $WP_JAVA_PARAMS \
    ${DBG_PROP} \
    com.ibm.websphere.update.launch.Launcher \
    com.ibm.websphere.update.silent.UpdateInstaller $@
fi

echo End of [ "$LaunchTitle" ]
echo 
exit $success_rc
